<no title> — cis_interface 0.3.0 documentation

Model YAML:

     1
     2
     3
     4
     5
     6
     7
     8
     9
    10
    11
    12
    13
    14
    15
    16
    17
    18
    19
    20
    21
    22
    models:
      - name: python_modelA
        language: python
        args: ./src/formatted_io2_modelA.py
        inputs: inputA
        outputs: outputA

      - name: python_modelB
        language: python
        args: ./src/formatted_io2_modelB.py
        inputs: inputB
        outputs: outputB

    connections:
      - input: outputA  # Connection between model A output & model B input
        output: inputB
      - input: ./Input/input.txt  # Connection between file and model A input
        output: inputA
        filetype: table
      - input: outputB  # Connection between model B output and file
        output: ./output.txt
        filetype: table

(Example in other languages)